.. flownetpy documentation master file, created by
   sphinx-quickstart on Fri Aug 28 19:36:58 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to flownetpy
====================
.. include:: about.rst

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   Formalism <formalism>

Indices and tables
==================
* :ref:`modindex`

